Tutorials
=========

To get started with ``laddu``, please refer to the following tutorials for the basic operation of the library and the API reference for more details.

.. toctree::
   :maxdepth: 1
  
   unbinned_fit
   binned_fit
   live_plotting
